searchNodes=[{"doc":"A behaviour for using Ecto-validated Airtable models in an Elixir App.Add use ExAirtable.Phoenix.Model to any model that implements both Airtable and Ecto schema validation. The advantage of this behaviour is to allow you to use generic patterns to query all models using the same methods. See ExAirtable.Phoenix.Repo for more details about some of the methods you can call with models that implement this behaviour.","ref":"ExAirtable.Phoenix.Model.html","title":"ExAirtable.Phoenix.Model","type":"behaviour"},{"doc":"","ref":"ExAirtable.Phoenix.Model.html#c:validate/1","title":"ExAirtable.Phoenix.Model.validate/1","type":"callback"},{"doc":"Functions to deal with finding and converting ExAirtable structs into Ecto Schema-fied models for your app.Also contains helper functions for finding, filtering, and injecting fields and relationships from any model that implements the ExAirtable.Phoenix.Model behaviour.These methods roughly correspond to similar methods in the Ecto.Repo library, to ensure a smooth upgrade path for apps that want to move from Airtable to a hosted Postgres or other database back-end.","ref":"ExAirtable.Phoenix.Repo.html","title":"ExAirtable.Phoenix.Repo","type":"module"},{"doc":"Return all valid model records from the Airtable cache.Pass in the name of the module that implements the ExAirtable.Phoenix.Model behaviour.Returns records from the model that pass validation. This might be a subset of the records that you find in Airtable, depending on how strict your validation is.","ref":"ExAirtable.Phoenix.Repo.html#all/1","title":"ExAirtable.Phoenix.Repo.all/1","type":"function"},{"doc":"Filter a list of model records to just the ones where key matches value.You can pass a pre-found list of records, or just the name of a model.Returns an empty list [] if nothing matches.Examplesiex&gt; get_by(MyApp.Posts.Comment, :airtable_id, &quot;rec1234&quot;) [%MyApp.Posts.Comment{}, ...] iex&gt; get_by(list_of_posts, :airtable_id, &quot;rec1234&quot;) [%MyApp.Posts.Posts{}, ...]","ref":"ExAirtable.Phoenix.Repo.html#get_by/3","title":"ExAirtable.Phoenix.Repo.get_by/3","type":"function"},{"doc":"Filter all records from a given model to just the ones where one of the values at key matches value.Because Airtable deals with &quot;many-to-many&quot; fields and &quot;multiple choice&quot; fields by returning JSON arrays, it's helpful to have a way to find records where something in that array matches a particular value.You can pass a pre-found list of records, or just the name of a model.Examplesiex&gt; get_relationship(MyApp.Post.Comment, :user, my_user.airtable_id) [%MyApp.Posts.Comment{}, ...] iex&gt; get_relationship(MyApp.Post.Post, :tags, &quot;Tech&quot;) [%MyApp.Posts.Post{}, ...]","ref":"ExAirtable.Phoenix.Repo.html#get_relationship/3","title":"ExAirtable.Phoenix.Repo.get_relationship/3","type":"function"},{"doc":"Replace Airtable &quot;list of IDS&quot; related field references with actual model objects.You can pass a pre-found list of records, or just the name of a model.Examplesiex&gt; inject_relationship(post, :comments, MyApp.Post.Comment) %MyApp.Posts.Post{comments: [%MyApp.Posts.Comment{}, ...]}","ref":"ExAirtable.Phoenix.Repo.html#inject_relationship/3","title":"ExAirtable.Phoenix.Repo.inject_relationship/3","type":"function"},{"doc":"Same as get_by/3 but only returns the first match.","ref":"ExAirtable.Phoenix.Repo.html#one/3","title":"ExAirtable.Phoenix.Repo.one/3","type":"function"},{"doc":"Validation functions that will be automatically included when you use the ExAirtable.Phoenix.Model module.","ref":"ExAirtable.Phoenix.Validators.html","title":"ExAirtable.Phoenix.Validators","type":"module"},{"doc":"Ensure that at least one of a given list of fields has data.fields should be a list of atoms, eg: [:text, :description, :url].","ref":"ExAirtable.Phoenix.Validators.html#validate_one_of/2","title":"ExAirtable.Phoenix.Validators.validate_one_of/2","type":"function"},{"doc":"ExAirtablePhoenixA set of sensible defaults for using ExAirtable with Phoenix, using Ecto's embedded schemas for validation.The overall goal is to make working with ExAirtable in Phoenix projects similar enough to working with Ecto to provide a migration pathway should your app outgrow Airtable as a back-end. At the same time, many (most?) apps will never come close to outgrowing Airtable, so you might as well have a nice time using it :)Because ExAirtable returns general-purpose structs that conform to the Airtable API specifications, it's often nice to be able to further validate those structs to domain-specific models. For example, ExAirtable might return something like this for your &quot;blogging&quot; app:%ExAirtable.Airtable.Record{ createdTime: &quot;2016-05-20T01:00:23.000Z&quot;, fields: %{ &quot;Email&quot; =&gt; &quot;my@email.org&quot;, &quot;Comments&quot; =&gt; [&quot;recg6cWUjaSxrShNy&quot;, &quot;recE2sCYzvbgbDUAZ&quot;, &quot;recJyXQOKlQRS38n7&quot;], &quot;Name&quot; =&gt; &quot;Some App User&quot;, &quot;Useless Field&quot; =&gt; &quot;Whatever&quot; }, id: &quot;recIbeH41sLn4nF6t&quot; }...when what you really want is something more like this:%MyApp.User{ name: &quot;Some App User&quot;, email: &quot;my@email.org&quot;, comments: [%MyApp.Comment{}, %MyApp.Comment{}, ...] }The thinking is, since Ecto has such nice embedded schema support, why reinvent the wheel? This library allows you to do a relatively small amount of setup by defining models that link to Airtable, optionally filter the resulting values, and then use Ecto embedded schemas to validate and cast them into domain models.Continuing the above &quot;blogging&quot; app example, you might have a model defined like this:defmodule MyApp.User do use ExAirtable.Phoenix.Model # Details about your Base def base do %ExAirtable.Config.Base{ api_key: &quot;your key&quot;, id: &quot;your base ID&quot; } end # This would be the name of the table in your Airtable base @impl ExAirtable.Table def name, do: &quot;Users&quot; # Convert the Airtable field names to your app&#39;s field names. @impl ExAirtable.Table def schema do %{ &quot;Email&quot; =&gt; :email, &quot;First Name&quot; =&gt; :first_name, &quot;Last Name&quot; =&gt; :last_name } end # This is Ecto, doing the work of casting and schema definition embedded_schema do field(:airtable_id, :string) field(:email, :string) field(:first_name, :string) field(:last_name, :string) end @doc &quot;&quot;&quot; Returns a `%User{}` given a valid set of attributes. On failure, returns `{:error, %Ecto.Changeset{}}` &quot;&quot;&quot; @impl ExAirtable.Phoenix.Model def validate(attrs \\\\ %{}) do %__MODULE__{} |&gt; cast(attrs, [:airtable_id, :email, :first_name, :last_name]) |&gt; validate_required([:airtable_id, :email, :first_name]) |&gt; apply_action(:save) end endOnce you've defined your model object this way, you can use the functions in ExAirtable.Phoenix.Repo to automatically retrieve, convert, etc. items out of your ExAirtable cache:defmodule MyApp.UserContext do alias ExAirtable.Phoenix.Repo alias MyApp.User @doc &quot;&quot;&quot; Find a User by email Returns `{:ok, %User{}}` on success. Returns `{:error, :not_found}` on failure. &quot;&quot;&quot; def find_by_email(email) do if user = Repo.one(User, :email, email) do {:ok, user} else {:error, :not_found} end end @doc &quot;&quot;&quot; List all valid users &quot;&quot;&quot; def list_users do Repo.all(User) end endBe sure to check out ExAirtable.Phoenix.Repo for more details and examples. Also, make sure to look at the ExAirtable docs themselves for more information about how you configure ExAirtable for your app.","ref":"readme.html","title":"ExAirtablePhoenix","type":"extras"},{"doc":"If available in Hex, the package can be installed by adding ex_airtable_phoenix to your list of dependencies in mix.exs:def deps do [ {:ex_airtable_phoenix, &quot;~&gt; 0.1.0&quot;} ] endIf you prefer to use the latest build, point straight to github: [ {:ex_airtable_phoenix, git: &quot;https://github.com/exploration/ex_airtable_phoenix.git&quot;} ]","ref":"readme.html#installation","title":"ExAirtablePhoenix - Installation","type":"extras"},{"doc":"More documentation can be found at https://hexdocs.pm/ex_airtable_phoenix.","ref":"readme.html#documentation","title":"ExAirtablePhoenix - Documentation","type":"extras"}]